Credits
=======

``pem`` is written and maintained by Hynek Schlawack.

The development is kindly supported by `Variomedia AG <https://www.variomedia.de/>`_.

Contributors
------------

The following wonderful people contributed directly or indirectly to this project:

- `blag <https://github.com/blag>`_
- `Glyph <https://github.com/glyph>`_
- `lvh <https://github.com/lvh>`_

Please add yourself here alphabetically when you submit your first pull request.
